@@ -1,6 +1,6 @@
 import bybit
 #
-client = bybit.bybit(test=True, api_key="rHWpqFVAnlTdqTNODX", api_secret="eDZZGzzkojYaf96xKUowGOhlNQEuebOPNEE1")
+client = bybit.bybit(test=False, api_key="LVaw7yxFRZUU1IH8kv", api_secret="CDsT3G0eDGrZlqPmPw8WhpNvdjy3D61ztY1E")
 #
 # # # Get server time
 # print(client.Common.Common_get().result()[0])
@@ -19,7 +19,7 @@ client = bybit.bybit(test=True, api_key="rHWpqFVAnlTdqTNODX", api_secret="eDZZGz
 # print(client.Positions.Positions_closePnlRecords(symbol="BTCUSD").result()[0]["result"][0])
 # #
 # # # Query account positions
-# print(client.Positions.Positions_myPosition().result())
+print(client.Positions.Positions_myPosition(symbol="BTCUSD").result())
 # #
 # # #Place an Active Order
 # print(client.Order.Order_new(side="Buy",symbol="BTCUSD",order_type="Limit",qty=1,price=8300,time_in_force="GoodTillCancel").result())
